use askama::Template;
use askama_axum::IntoResponse;
use axum::{extract::Query, routing, Router};
use serde::Deserialize;

struct MenuItem {
    label: String,
    id: String,
    current: bool,
}

#[derive(Deserialize)]
struct MenuParameters {
    mobile: bool,
}

#[derive(Template)]
#[template(path = "layout/nav/profile-menu-items.html")]
struct MenuResponse {
    mobile: bool,
    items: Vec<MenuItem>,
}

impl MenuResponse {
    fn get_classes(&self, is_current_item: &bool) -> String {
        let common_classes = match self.mobile {
            true => "block px-4 py-2 text-base font-medium text-gray-500 hover:bg-gray-100 hover:text-gray-800".to_string(),
            false => "block px-4 py-2 text-sm text-gray-700".to_string(),
        };
        match (self.mobile, is_current_item) {
            (true, true) => common_classes + "", // ???
            (true, false) => common_classes + "",
            (false, true) => common_classes + " bg-gray-100",
            (false, false) => common_classes + "",
        }
    }
}

async fn menu(Query(params): Query<MenuParameters>) -> impl IntoResponse {
    MenuResponse {
        mobile: params.mobile,
        items: vec![
            MenuItem {
                label: "Votre profil".to_string(),
                id: "profile".to_string(),
                current: false,
            },
            MenuItem {
                label: "Paramètres".to_string(),
                id: "settings".to_string(),
                current: false,
            },
            MenuItem {
                label: "Déconnexion".to_string(),
                id: "logout".to_string(),
                current: false,
            },
        ],
    }.into_response()
}

pub fn get_routes() -> Router {
    Router::new()
        .route("/menu", routing::get(menu))
}